@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "iso-639" "1.1.0"
+(define-package "iso-639" "20251114.1512"
   "ISO 639."
   '((emacs "27.1"))
   :url "https://codeberg.org/tomenzgg/emacs-iso-639"
